@@ -251,4 +251,20 @@ void loadForthData(QMultiHash<char, QLatin1String> &types,
                    QMultiHash<char, QLatin1String> &builtin,
                    QMultiHash<char, QLatin1String> &literals,
                    QMultiHash<char, QLatin1String> &other);
+/********************************************************/
+/***   GDScript DATA  **************************************/
+/********************************************************/
+void loadGDScriptData(QMultiHash<char, QLatin1String> &types,
+                      QMultiHash<char, QLatin1String> &keywords,
+                      QMultiHash<char, QLatin1String> &builtin,
+                      QMultiHash<char, QLatin1String> &literals,
+                      QMultiHash<char, QLatin1String> &other);
+/********************************************************/
+/***   TOML DATA  **************************************/
+/********************************************************/
+void loadTOMLData(QMultiHash<char, QLatin1String> &types,
+                  QMultiHash<char, QLatin1String> &keywords,
+                  QMultiHash<char, QLatin1String> &builtin,
+                  QMultiHash<char, QLatin1String> &literals,
+                  QMultiHash<char, QLatin1String> &other);
 #endif
