@@ -23,7 +23,7 @@ bool UrlHandler::isUrlSchemeLocal(const QUrl &url) {
            (scheme == QLatin1String("file") && Note::fileUrlIsNoteInCurrentNoteFolder(url));
 }
 
-void UrlHandler::openUrl(QString urlString) {
+void UrlHandler::openUrl(QString urlString, const bool openInNewTab) {
     /* examples:
      * - <note://MyNote> opens the note "MyNote"
      * - <note://my-note-with-spaces-in-the-name> opens the note "My Note with
@@ -59,9 +59,9 @@ void UrlHandler::openUrl(QString urlString) {
     } else if (urlString.startsWith(QStringLiteral("file://attachments"))) {
         handleFileAttachmentUrl(urlString);
     } else if (scheme == QStringLiteral("noteid")) {
-        handleNoteIdUrl(urlString);
+        handleNoteIdUrl(urlString, openInNewTab);
     } else if (scheme == QStringLiteral("note") || isNoteFileUrl) {
-        handleNoteUrl(urlString, fragment);
+        handleNoteUrl(urlString, fragment, openInNewTab);
     } else if (scheme == QStringLiteral("task")) {
         MainWindow::instance()->openTodoDialog(url.host());
     } else if (scheme == QStringLiteral("deck")) {
@@ -81,36 +81,45 @@ void UrlHandler::openUrl(QString urlString) {
 }
 
 void UrlHandler::handleNextcloudDeckUrl(const QString &urlString) {
-    NextcloudDeckService nextcloudDeckService(MainWindow::instance());
+    // Parse the card ID directly from the URL path to avoid requiring
+    // a pre-configured board ID that exactly matches the URL
+    auto cardId = NextcloudDeckService::parseCardIdFromUrlDirectly(urlString);
+    qDebug() << __func__ << "cardId: " << cardId;
 
-    if (nextcloudDeckService.isEnabled()) {
-        auto cardId = nextcloudDeckService.parseCardIdFromUrl(urlString);
-        qDebug() << __func__ << "cardId: " << cardId;
-
-        if (cardId > 0) {
-            // Open the Nextcloud Deck dialog with the cardId
-            MainWindow::instance()->openNextcloudDeckDialog(cardId);
-        }
+    if (cardId > 0) {
+        // Open the Nextcloud Deck dialog with the cardId.
+        // We do not require isEnabled() here because the user explicitly clicked
+        // a Deck link and we should honour that regardless of whether the Deck
+        // integration is fully configured for card creation.
+        MainWindow::instance()->openNextcloudDeckDialog(cardId);
     }
 }
 
-void UrlHandler::handleNoteIdUrl(const QString &urlString) {
-    static const QRegularExpression re(QStringLiteral(R"(^noteid:\/\/note-(\d+)$)"));
+void UrlHandler::handleNoteIdUrl(const QString &urlString, bool openInNewTab) {
+    static const QRegularExpression re(QStringLiteral(R"(^noteid:\/\/(\d+)$)"));
     QRegularExpressionMatch match = re.match(urlString);
 
     if (match.hasMatch()) {
         int noteId = match.captured(1).toInt();
         Note note = Note::fetch(noteId);
         if (note.isFetched()) {
-            // set current note
-            MainWindow::instance()->setCurrentNote(std::move(note));
+            auto mw = MainWindow::instance();
+            if (openInNewTab) {
+                mw->openNoteInTab(note, true);
+            } else {
+                // set current note
+                mw->setCurrentNote(std::move(note));
+            }
         }
     } else {
         qWarning() << "NoteIdUrlHandler malformed url: " << urlString;
     }
 }
 
-void UrlHandler::handleNoteUrl(const QString &urlString, const QString &fragment) {
+void UrlHandler::handleNoteUrl(const QString &urlString, const QString &fragment,
+                               bool openInNewTab) {
+    qDebug() << __func__ << " - urlString:" << urlString << " - openInNewTab:" << openInNewTab;
+
     Note note;
     const QUrl url(urlString);
     auto mw = MainWindow::instance();
@@ -127,8 +136,16 @@ void UrlHandler::handleNoteUrl(const QString &urlString, const QString &fragment
 
     // does this note really exist?
     if (note.isFetched()) {
-        // set current note
-        mw->setCurrentNote(std::move(note));
+        qDebug() << __func__ << " - note fetched, isFetched:" << note.isFetched()
+                 << " - openInNewTab:" << openInNewTab;
+        if (openInNewTab) {
+            // open note in a new tab
+            qDebug() << __func__ << " - calling openNoteInTab";
+            mw->openNoteInTab(note, true);
+        } else {
+            // set current note
+            mw->setCurrentNote(std::move(note));
+        }
 
         // Jump to the Markdown heading in the note that is represented by the url fragment
         if (!fragment.isEmpty()) {
